==> kui-web-terminal-container-v2.1.3-2.tar.gz: package/helm/mdist/controller/helm/history.js <==
/*
 * Copyright 2019 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { isUsage, doHelp, preprocessTable, formatTable } from '@kui-shell/plugin-kubectl';
import doExecWithStdout from './exec';
import commandPrefix from '../command-prefix';
function doHistory(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isUsage(args)) {
            return doHelp('helm', args);
        }
        const response = yield doExecWithStdout(args);
        const preTables = preprocessTable(response.split(/^(?=LAST SEEN|NAMESPACE|NAME\s+)/m));
        return formatTable('helm', undefined, undefined, args, preTables[0]);
    });
}
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/helm/history`, doHistory);
};
//# sourceMappingURL=history.js.map

==> kui-web-terminal-container-v2.3.3-6.tar.gz: package/helm/mdist/controller/helm/history.js <==
/*
 * Copyright 2019 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { doHelp, preprocessTable, formatTable } from '@kui-shell/plugin-kubectl';
import isUsage from './usage';
import doExecWithStdout from './exec';
function doHistory(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isUsage(args, 'history')) {
            return doHelp('helm', args);
        }
        const response = yield doExecWithStdout(args);
        const preTables = preprocessTable(response.split(/^(?=LAST SEEN|NAMESPACE|NAME\s+)/m));
        return formatTable('helm', undefined, undefined, args, preTables[0]);
    });
}
export default (registrar) => {
    registrar.listen('/helm/history', doHistory);
};
//# sourceMappingURL=history.js.map
